/*
 * Copyright (C) 2010 ZXing authors
 * Copyright 2011 Robert Theis
 * Copyright 2012 Jaime Navarro Santapau
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file    DecodeHandler.java
 * @author  Jaime Navarro Santapau
 * @brief   Contiene los métodos y atributos de la clase DecodeHandler
 * @date    Última modificación Diciembre 2012
 * 
 */

package edu.uoc.ocr;

import com.googlecode.tesseract.android.TessBaseAPI;

import edu.uoc.ocr.R;
import edu.uoc.ocr.BeepManager;
import edu.uoc.ocr.CaptureActivityForOcr;

import android.os.Handler;
import android.os.Looper;
import android.os.Message;

/**
 * @class DecodeHandler
 * @brief Clase que envía los datos de la imagen para realizar el procesado OCR.
 */
final class DecodeHandler extends Handler {

	private final CaptureActivityForOcr activity;
	private boolean running = true;
	private final TessBaseAPI baseApi;
	private BeepManager beepManager;

	DecodeHandler(CaptureActivityForOcr activity) {
		this.activity = activity;
		baseApi = activity.getBaseApi();
		beepManager = new BeepManager(activity);
		beepManager.updatePrefs();
	}

	@Override
	public void handleMessage(Message message) {
		if (!running) {
			return;
		}
		switch (message.what) {
		case R.id.ocr_decode:
			ocrDecode((byte[]) message.obj, message.arg1, message.arg2);
			break;
		case R.id.quit:
			running = false;
			Looper.myLooper().quit();
			break;
		}
	}

	/**
	 * @brief Iniciar una AsyncTask para realizar una decodificación de OCR para
	 *        el modo de disparo único.
	 * 
	 * @param data Imagen de datos
	 * @param width ancho de la imagen
	 * @param height altura de la imagen
	 */
	private void ocrDecode(byte[] data, int width, int height) {
		beepManager.playBeepSoundAndVibrate();
		activity.displayProgressDialog();

		// Launch OCR asynchronously, so we get the dialog box displayed
		// immediately
		new OcrRecognizeAsyncTask(activity, baseApi, data, width, height)
				.execute();
	}

}


