/*
 * Copyright 2011 Robert Theis
 * Copyright 2012 Jaime Navarro Santapau
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file    LanguageCodeHelper.java
 * @author  Jaime Navarro Santapau
 * @brief   Contiene los métodos y atributos de la clase LanguageCodeHelper
 * @date    Última modificación Diciembre 2012
 * 
 */

package edu.uoc.ocr;

import android.content.Context;
import android.content.res.Resources;
import android.util.Log;

import edu.uoc.ocr.R;

/**
 * @class LanguageCodeHelper
 * @brief Clase para el manejo de las funciones relacionadas con la conversión
 *        entre los códigos de idioma estándar, y la conversión de códigos de
 *        idioma para los nombres de idiomas.
 */
public class LanguageCodeHelper {
	public static final String TAG = "LanguageCodeHelper";

	/**
	 * @brief Constructor privado para hacer cumplir noninstantiability
	 */
	private LanguageCodeHelper() {
		throw new AssertionError();
	}

	/**
	 * @brief Mapa del dado ISO 639-3 códigos de idioma para el nombre de un
	 *        idioma, por ejemplo, "Español"
	 * 
	 * @param context
	 *            interfaz de llamar entorno de aplicación. Se necesita para
	 *            acceder a valores de strings.xml.
	 * @param languageCode
	 *            ISO 639-3 lenguaje de código
	 * @return language nombre
	 */
	public static String getOcrLanguageName(Context context, String languageCode) {
		Resources res = context.getResources();
		String[] language6393 = res.getStringArray(R.array.iso6393);
		String[] languageNames = res.getStringArray(R.array.languagenames);
		int len;

		// Finds the given language code in the iso6393 array, and takes the
		// name with the same index
		// from the languagenames array.
		for (len = 0; len < language6393.length; len++) {
			if (language6393[len].equals(languageCode)) {
				Log.d(TAG, "getOcrLanguageName: " + languageCode + "->"
						+ languageNames[len]);
				return languageNames[len];
			}
		}

		Log.d(TAG, "languageCode: Could not find language name for ISO 693-3: "
				+ languageCode);
		return languageCode;
	}

}
