/*
 * Copyright 2011 Robert Theis
 * Copyright 2012 Jaime Navarro Santapau
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file    OcrCharacterHelper.java
 * @author  Jaime Navarro Santapau
 * @brief   Contiene los métodos y atributos de la clase OcrCharacterHelper
 * @date    Última modificación Diciembre 2012
 * 
 */

package edu.uoc.ocr;

import android.content.SharedPreferences;

/**
 * @class OcrCharacterHelper
 * @brief Clase auxiliar para habilitar las listas negras de caracteres / listas
 *        blancas en un fichero de patrones específico.
 */
public class OcrCharacterHelper {
	
	public static final String KEY_CHARACTER_BLACKLIST_MANUAL = "preference_character_blacklist_manual";
	public static final String KEY_CHARACTER_BLACKLIST_CATALAN = "preference_character_blacklist_catalan";
	public static final String KEY_CHARACTER_BLACKLIST_ENGLISH = "preference_character_blacklist_english";
	public static final String KEY_CHARACTER_BLACKLIST_SPANISH = "preference_character_blacklist_spanish";
	
	public static final String KEY_CHARACTER_WHITELIST_MANUAL = "preference_character_whitelist_manual";
	public static final String KEY_CHARACTER_WHITELIST_CATALAN = "preference_character_whitelist_catalan";
	public static final String KEY_CHARACTER_WHITELIST_ENGLISH = "preference_character_whitelist_english";
	public static final String KEY_CHARACTER_WHITELIST_SPANISH = "preference_character_whitelist_spanish";

	private OcrCharacterHelper() {
	} // Private constructor to enforce noninstantiability

	public static String getDefaultBlacklist(String languageCode) {

		if (languageCode.equals("man")) {
			return "";
		} // Manual
		else if (languageCode.equals("cat")) {
			return "";
		} // Catalan
		else if (languageCode.equals("eng")) {
			return "";
		} // English
		else if (languageCode.equals("spa")) {
			return "";
		} // Spanish
		else {
			throw new IllegalArgumentException();
		}
	}

	public static String getDefaultWhitelist(String languageCode) {
		if (languageCode.equals("man")) {
			return "*:/.,ABCDEFGHIJKLMNÑOPQRSTUVWXYZacehnoprstu0123456789";
		} // Arabic
		else if (languageCode.equals("cat")) {
			return "";
		} // Catalan
		else if (languageCode.equals("eng")) {
			return "";
		} // English
		else if (languageCode.equals("spa")) {
			return "";
		} // Spanish
		else {
			throw new IllegalArgumentException();
		}
	}

	public static String getBlacklist(SharedPreferences prefs,
			String languageCode) {
		if (languageCode.equals("man")) {
			return prefs.getString(KEY_CHARACTER_BLACKLIST_MANUAL,
					getDefaultBlacklist(languageCode));
		} // Manual

		else if (languageCode.equals("cat")) {
			return prefs.getString(KEY_CHARACTER_BLACKLIST_CATALAN,
					getDefaultBlacklist(languageCode));
		} else if (languageCode.equals("eng")) {
			return prefs.getString(KEY_CHARACTER_BLACKLIST_ENGLISH,
					getDefaultBlacklist(languageCode));
		} else if (languageCode.equals("spa")) {
			return prefs.getString(KEY_CHARACTER_BLACKLIST_SPANISH,
					getDefaultBlacklist(languageCode));
		} else {
			throw new IllegalArgumentException();
		}
	}

	public static String getWhitelist(SharedPreferences prefs,
			String languageCode) {
		if (languageCode.equals("man")) {
			return prefs.getString(KEY_CHARACTER_WHITELIST_MANUAL,
					getDefaultWhitelist(languageCode));
		} // Manual

		else if (languageCode.equals("cat")) {
			return prefs.getString(KEY_CHARACTER_WHITELIST_CATALAN,
					getDefaultWhitelist(languageCode));
		} else if (languageCode.equals("eng")) {
			return prefs.getString(KEY_CHARACTER_WHITELIST_ENGLISH,
					getDefaultWhitelist(languageCode));
		} else if (languageCode.equals("spa")) {
			return prefs.getString(KEY_CHARACTER_WHITELIST_SPANISH,
					getDefaultWhitelist(languageCode));
		} else {
			throw new IllegalArgumentException();
		}
	}

	public static void setBlacklist(SharedPreferences prefs,
			String languageCode, String blacklist) {
		if (languageCode.equals("man")) {
			prefs.edit().putString(KEY_CHARACTER_BLACKLIST_MANUAL, blacklist)
					.commit();
		} else if (languageCode.equals("cat")) {
			prefs.edit().putString(KEY_CHARACTER_BLACKLIST_CATALAN, blacklist)
					.commit();
		} else if (languageCode.equals("eng")) {
			prefs.edit().putString(KEY_CHARACTER_BLACKLIST_ENGLISH, blacklist)
					.commit();
		} else if (languageCode.equals("spa")) {
			prefs.edit().putString(KEY_CHARACTER_BLACKLIST_SPANISH, blacklist)
					.commit();
		} else {
			throw new IllegalArgumentException();
		}
	}

	public static void setWhitelist(SharedPreferences prefs,
			String languageCode, String whitelist) {
		if (languageCode.equals("man")) {
			prefs.edit().putString(KEY_CHARACTER_WHITELIST_MANUAL, whitelist)
					.commit();
		} else if (languageCode.equals("cat")) {
			prefs.edit().putString(KEY_CHARACTER_WHITELIST_CATALAN, whitelist)
					.commit();
		} else if (languageCode.equals("eng")) {
			prefs.edit().putString(KEY_CHARACTER_WHITELIST_ENGLISH, whitelist)
					.commit();
		} else if (languageCode.equals("spa")) {
			prefs.edit().putString(KEY_CHARACTER_WHITELIST_SPANISH, whitelist)
					.commit();
		} else {
			throw new IllegalArgumentException();
		}
	}
}
