/*
 * Copyright (C) 2011 Google Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

/**
 * @file    Convert.java
 * @author  alanv@google.com (Alan Viverette)
 * @author  Jaime Navarro Santapau
 * @brief   Contiene los métodos y atributos de la clase Convert.
 * @date    Última modificación Diciembre 2012
 * 
 */

package com.googlecode.leptonica.android;

/**
 * @class Convert
 * @brief Métodos de conversión de la profundidad de bits de la imagen.
 */
public class Convert {
	static {
		System.loadLibrary("lept");
	}

	/**
	 * @brief Converts an image of any bit depth to 8-bit grayscale.
	 * 
	 * @param pixs
	 *            Source pix of any bit-depth.
	 * @return a new Pix image or <code>null</code> on error
	 */
	public static Pix convertTo8(Pix pixs) {
		if (pixs == null)
			throw new IllegalArgumentException("Source pix must be non-null");

		int nativePix = nativeConvertTo8(pixs.mNativePix);

		if (nativePix == 0)
			throw new RuntimeException("Failed to natively convert pix");

		return new Pix(nativePix);
	}

	// ***************
	// * NATIVE CODE *
	// ***************

	private static native int nativeConvertTo8(int nativePix);
}
